## About

[Vundle] is a short cut for **V**imb**undle** and is a [Vim] plugin manager.

## Quick start

1. Setup [Vundle]:

        git clone http://github.com/gmarik/vundle.git ~/.vim/vundle.git

2. Configure bundles:

   Put into your `~/.vimrc`:

        set rtp+=~/.vim/vundle.git/ 
        call vundle#rc()

        " Bundles:
        Bundle "L9"
        Bundle "FuzzyFinder"
        Bundle "rails.vim"
        Bundle "ack.vim"
        Bundle "git://git.wincent.com/command-t.git"
        " ...

        " NOTE: if some plugins fail to work, put the config *between* lines:
        " filetype off
        " "Bundles here
        " filetype plugin indent on 

3. Install configured bundles:

   Launch `vim`, run `:BundleInstall`. 
   *Windows users* see _Requrements / Windows_ section

   Installing requires [Git] and triggers [Git clone](http://gitref.org/creating/#clone) for each configured repo to `~/.vim/bundle/`.

## Why Vundle

[Vundle] allows to:

- keep track and configure your scripts right in `.vimrc`
- [install] configured scripts (aka bundle) 
- [update] configured scripts
- [search] [all available vim scripts] by name
- [clean] unused scripts up
- run above actions in a *single keypress* with [interactive mode]

Also [Vundle]:

- manages runtime path of your installed scripts
- regenerates helptag atomatically

## Docs

see [`:h vundle`](vundle/blob/master/doc/vundle.txt#L1) vimdoc for more details.

## Examples

   See [gmarik's vimrc](https://github.com/gmarik/vimfiles/blob/1f4f26d42f54443f1158e0009746a56b9a28b053/vimrc#L136) for working example.

## Requirements:

   Vundle requires the `git` and `curl` commandline tools.  These can be
   installed through the regular means for your operating system.

### Windows support

   On Windows you can install `git` using
   [msysgit](http://code.google.com/p/msysgit/).

   The `curl` Windows binary can be found on the
   [curl website](http://curl.haxx.se/).  Copy the files to where you'd like
   to store them (`%PROGRAMFILES%\curl` is a pretty good choice).

   Both `git` and `curl` must be added to the PATH environment variable for
   Vundle to work.  The msysgit installer provides an option to add git to the
   path automatically.

   You can edit your Windows PATH environment variable by right-clicking
   on My Computer and selecting selecting Properties (Windows Vista/7 users
   must also click `Advanced System Settings`). Go to the Advanced tab and
   click `Environment Variables...`.  Append the path where you installed
   `curl` to the `Path` system variable.

## Contributors
* [Brad Anderson](http://github.com/eco) (windows support)
* [Ryan W](http://github.com/rygwdn)
* [gmarik](http://github.com/gmarik)

## Inspiration and ideas from

* [pathogen]
* [bundler]
* [Scott Bronson](http://github.com/bronson)

## Also

* Vundle was developed and tested with [Vim] 7.3 on `OSX` and `Linux`
* Vundle tries to be as [KISS](http://en.wikipedia.org/wiki/KISS_principle) as possible

## TODO:
[Vundle] is a work in progress so any ideas/patches appreciated

* √ activate newly added bundles on .vimrc reload or after :BundleInstall
* √ use preview window for search results
* √ vim documentation
* tests
* improve error handling
* :VundleUpdate - self.update
* handle dependencies
* allow specify revision/version?
* search by description aswell
* show descrption in search results
* instead sourcing .vimrc before installation come up with another solution
* make it rock!

[Vundle]:http://github.com/gmarik/vundle
[Pathogen]:http://github.com/tpope/vim-pathogen/
[Bundler]:http://github.com/wycats/bundler/
[Vim]:http://vim.org
[Git]:http://git-scm.com
[all available vim scripts]:http://vim-scripts.org/vim/scripts.html

[install]:https://github.com/gmarik/vundle/blob/master/doc/vundle.txt#L96-110
[update]:https://github.com/gmarik/vundle/blob/master/doc/vundle.txt#L112-117
[search]:https://github.com/gmarik/vundle/blob/master/doc/vundle.txt#L119-137
[clean]:https://github.com/gmarik/vundle/blob/master/doc/vundle.txt#L139-150
[interactive mode]:https://github.com/gmarik/vundle/blob/master/doc/vundle.txt#L152-175
